@@ -41,7 +41,7 @@ import os
 import copy
 import locale
 import importlib
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Text, Tuple, Union  # noqa: F401
+from typing import Any, Dict, List, Optional, Set, Text, Union  # noqa: F401
 
 import six
 import ldap
@@ -111,6 +111,14 @@ _superordinates = set()  # type: Set[str]
 containers = []  # type: List[UdmModule]
 
 
+@univention.admin._ldap_cache(ttl=3600)
+def _ldap_operational_attribute_names(lo):  # type: (univention.admin.uldap.access) -> Set[str]
+	schema = lo.get_schema()
+	attrs = [schema.get_obj(ldap.schema.models.AttributeType, x) for x in schema.listall(ldap.schema.models.AttributeType)]
+	usages = [ldap.schema.models.AttributeUsage[o] for o in ('directoryoperation', 'dsaoperation', 'distributedoperation')]
+	return {n.lower() for a in attrs for n in a.names if a.usage in usages}
+
+
 def update():
 	# type: () -> None
 	"""
@@ -230,36 +238,15 @@ def init(lo, position, module, template_object=None, force_reload=False):
 		ud.debug(ud.ADMIN, ud.INFO, 'modules_init: got template object %s' % template_object.dn)
 		template_object.open()
 
-		# add template ext. attr. defaults
-		if hasattr(template_object, 'property_descriptions'):
-			for property_name, property in template_object.property_descriptions.items():
-				if not (property_name == "name" or property_name == "description"):
-					default = property.base_default
-					if default and property_name in module.property_descriptions:
-						if property.multivalue:
-							if module.property_descriptions[property_name].multivalue:
-								module.property_descriptions[property_name].base_default = list(default)
-						else:
-							module.property_descriptions[property_name].base_default = default
-						ud.debug(ud.ADMIN, ud.INFO, "modules.init: added template default (%s) to property %s" % (property.base_default, property_name))
-
 		# add template defaults
-		for key in template_object.keys():
-			if not (key == "name" or key == "description"):  # these keys are part of the template itself
-				if key == '_options':
-					if template_object[key] != [''] and template_object[key] != []:
-						for option in module.options.keys():
-							module.options[option].default = option in template_object[key]
-				else:
-					if template_object.descriptions[key].multivalue:
-						if module.property_descriptions[key].multivalue:
-							module.property_descriptions[key].base_default = list(template_object[key])
-						else:
-							ud.debug(ud.ADMIN, ud.INFO, 'modules.init: template and object values not both multivalue !!')
-
-					else:
-						module.property_descriptions[key].base_default = template_object[key]
-					module.property_descriptions[key].templates.append(template_object)
+		for key, tmpl in template_object.items():
+			if key == '_options':
+				if tmpl != [''] and tmpl != []:
+					for option in module.options.keys():
+						module.options[option].default = option in tmpl
+			elif key not in {"name", "description"}:  # these keys are part of the template itself
+				module.property_descriptions[key].base_default = copy.copy(tmpl)
+				module.property_descriptions[key].templates.append(template_object)
 		ud.debug(ud.ADMIN, ud.INFO, 'modules_init: module.property_description after template: %s' % module.property_descriptions)
 	else:
 		ud.debug(ud.ADMIN, ud.INFO, 'modules_init: got no template')
@@ -401,6 +388,7 @@ def update_extended_attributes(lo, module, position):
 		# get CLI name
 		pname = attrs['univentionUDMPropertyCLIName'][0].decode('UTF-8', 'replace')
 		object_class = attrs.get('univentionUDMPropertyObjectClass', [])[0].decode('UTF-8', 'replace')
+		ldap_attribute_name = attrs['univentionUDMPropertyLdapMapping'][0].decode('UTF-8', 'replace')
 		if name(module) == 'settings/usertemplate' and object_class == 'univentionMail' and b'settings/usertemplate' not in attrs.get('univentionUDMPropertyModule', []):
 			continue  # since "mail" is a default option, creating a usertemplate with any mail attribute would raise Object class violation: object class 'univentionMail' requires attribute 'uid'
 
@@ -492,10 +480,10 @@ def update_extended_attributes(lo, module, position):
 		)
 
 		# add LDAP mapping
-		if attrs['univentionUDMPropertyLdapMapping'][0].lower() != b'objectClass'.lower():
-			module.mapping.register(pname, attrs['univentionUDMPropertyLdapMapping'][0].decode('UTF-8', 'replace'), unmap_method, map_method)
+		if ldap_attribute_name.lower() != 'objectclass':
+			module.mapping.register(pname, ldap_attribute_name, unmap_method, map_method)
 		else:
-			module.mapping.register(pname, attrs['univentionUDMPropertyLdapMapping'][0].decode('UTF-8', 'replace'), univention.admin.mapping.nothing, univention.admin.mapping.nothing)
+			module.mapping.register(pname, ldap_attribute_name, univention.admin.mapping.nothing, univention.admin.mapping.nothing)
 
 		if hasattr(module, 'layout'):
 			tabname = _get_translation(lang, attrs, 'univentionUDMPropertyTranslationTabName;entry-%s', 'univentionUDMPropertyLayoutTabName', _('Custom'))
@@ -563,11 +551,15 @@ def update_extended_attributes(lo, module, position):
 			module.extended_udm_attributes.append(univention.admin.extended_attribute(
 				name=pname,
 				objClass=object_class,
-				ldapMapping=attrs['univentionUDMPropertyLdapMapping'][0].decode('UTF-8', 'replace'),
+				ldapMapping=ldap_attribute_name,
 				deleteObjClass=deleteObjectClass,
 				syntax=propertySyntaxString,
 				hook=propertyHook
 			))
+
+			if ldap_attribute_name.lower() in _ldap_operational_attribute_names(lo):
+				module.object._static_ldap_attributes.add(ldap_attribute_name)
+
 	module.property_descriptions = new_property_descriptions
 
 	# overwrite tabs that have been added by UDM extended attributes
